==> mongodb-6.0.25.gh.tar.gz: mongo-r6.0.25/src/mongo/db/profile_filter.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/profile_filter.h"

namespace mongo {

static std::shared_ptr<ProfileFilter> defaultProfileFilter;
static Mutex mutex = MONGO_MAKE_LATCH("ProfileFilter::mutex");

std::shared_ptr<ProfileFilter> ProfileFilter::getDefault() {
    stdx::lock_guard<Latch> lk(mutex);
    return defaultProfileFilter;
}

void ProfileFilter::setDefault(std::shared_ptr<ProfileFilter> filter) {
    stdx::lock_guard<Latch> lk(mutex);
    defaultProfileFilter = std::move(filter);
}

};  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/profile_filter.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/profile_filter.h"
#include "mongo/platform/mutex.h"

#include <mutex>
#include <shared_mutex>
#include <utility>

namespace mongo {

// std::atomic<std::shared_ptr> is not supported until GCC 12 and not in clang libc++ as of
// 9/28/2023
static std::shared_ptr<ProfileFilter> defaultProfileFilter;
static std::shared_mutex mutex;  // NOLINT

std::shared_ptr<ProfileFilter> ProfileFilter::getDefault() {
    std::shared_lock lock(mutex);  // NOLINT
    return defaultProfileFilter;
}

void ProfileFilter::setDefault(std::shared_ptr<ProfileFilter> filter) {
    stdx::unique_lock lock(mutex);  // NOLINT
    defaultProfileFilter = std::move(filter);
}

};  // namespace mongo
